@@ -12,9 +12,10 @@ from pymove.utils.constants import (
     STOP,
     TRAJ_ID,
 )
-from pymove.utils.log import progress_bar
+from pymove.utils.log import progress_bar, timer_decorator
 
 
+@timer_decorator
 def compress_segment_stop_to_point(
     move_data,
     label_segment=SEGMENT_STOP,
@@ -48,7 +49,7 @@ def compress_segment_stop_to_point(
          Used to create the stay points used in the compression.
          If the dataset already has the stop move, this
          parameter should be ignored.
-         Indicates the label of the id column in the user"s dataframe.
+         Indicates the label of the id column in the user"srs dataframe.
     dist_radius : Double, optional(30 by default)
         Used to create the stay points used in the compression.
         If the dataset already has the stop move, this
@@ -90,8 +91,8 @@ def compress_segment_stop_to_point(
             )
 
         print('...setting mean to lat and lon...')
-        lat_mean = np.full(move_data.shape[0], -1.0, dtype=np.float32)
-        lon_mean = np.full(move_data.shape[0], -1.0, dtype=np.float32)
+        lat_mean = np.full(move_data.shape[0], -1.0, dtype=np.float64)
+        lon_mean = np.full(move_data.shape[0], -1.0, dtype=np.float64)
 
         if drop_moves is False:
             lat_mean[move_data[~move_data[label_stop]].index] = np.NaN
@@ -108,7 +109,7 @@ def compress_segment_stop_to_point(
             filter_ = move_data[label_segment] == idx
 
             size_id = move_data[filter_].shape[0]
-            # veirify if filter is None
+            # verify if filter is None
             if size_id > 1:
                 # get first and last point of each stop segment
                 ind_start = move_data[filter_].iloc[[0]].index
@@ -161,7 +162,6 @@ def compress_segment_stop_to_point(
             % (shape_before, move_data.shape[0])
         )
 
-        print('-----------------------------------------------------\n')
         if not inplace:
             return move_data
     except Exception as e:
